@@ -1,27 +1,16 @@
-/* This file is part of the KDE libraries
-   Copyright (c) 2003 Scott Wheeler <wheeler@kde.org>
-   Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-   Copyright (c) 2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Scott Wheeler <wheeler@kde.org>
+    SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "ktreewidgetsearchline.h"
 
-#include <QtCore/QList>
-#include <QtCore/QTimer>
+#include <QList>
+#include <QTimer>
 #include <QApplication>
 #include <QContextMenuEvent>
 #include <QHeaderView>
@@ -84,7 +73,7 @@ void KTreeWidgetSearchLine::Private::_k_rowsInserted(const QModelIndex &parentIn
     }
 
     QTreeWidget *widget = nullptr;
-    foreach (QTreeWidget *tree, treeWidgets)
+    for (QTreeWidget *tree : qAsConst(treeWidgets))
         if (tree->model() == model) {
             widget = tree;
             break;
@@ -223,6 +212,7 @@ KTreeWidgetSearchLine::KTreeWidgetSearchLine(QWidget *q, QTreeWidget *treeWidget
             this, SLOT(_k_queueSearch(QString)));
 
     setClearButtonEnabled(true);
+    setPlaceholderText(tr("Search..."));
     setTreeWidget(treeWidget);
 
     if (!treeWidget) {
@@ -315,7 +305,7 @@ void KTreeWidgetSearchLine::updateSearch(const QString &pattern)
 {
     d->search = pattern.isNull() ? text() : pattern;
 
-    foreach (QTreeWidget *treeWidget, d->treeWidgets) {
+    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
         updateSearch(treeWidget);
     }
 }
@@ -377,13 +367,13 @@ void KTreeWidgetSearchLine::setTreeWidget(QTreeWidget *treeWidget)
 
 void KTreeWidgetSearchLine::setTreeWidgets(const QList<QTreeWidget *> &treeWidgets)
 {
-    foreach (QTreeWidget *treeWidget, d->treeWidgets) {
+    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
         disconnectTreeWidget(treeWidget);
     }
 
     d->treeWidgets = treeWidgets;
 
-    foreach (QTreeWidget *treeWidget, d->treeWidgets) {
+    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
         connectTreeWidget(treeWidget);
     }
 
@@ -508,27 +498,28 @@ bool KTreeWidgetSearchLine::canChooseColumnsCheck()
 
     const QTreeWidget *first = d->treeWidgets.first();
 
-    const unsigned int numcols = first->columnCount();
+    const int numcols = first->columnCount();
     // the listviews have only one column,
     if (numcols < 2) {
         return false;
     }
 
     QStringList headers;
-    for (unsigned int i = 0; i < numcols; ++i) {
+    headers.reserve(numcols);
+    for (int i = 0; i < numcols; ++i) {
         headers.append(first->headerItem()->text(i));
     }
 
     QList<QTreeWidget *>::ConstIterator it = d->treeWidgets.constBegin();
     for (++it /* skip the first one */; it != d->treeWidgets.constEnd(); ++it) {
         // the listviews have different numbers of columns,
-        if ((unsigned int)(*it)->columnCount() != numcols) {
+        if ((*it)->columnCount() != numcols) {
             return false;
         }
 
         // the listviews differ in column labels.
         QStringList::ConstIterator jt;
-        unsigned int i;
+        int i;
         for (i = 0, jt = headers.constBegin(); i < numcols; ++i, ++jt) {
             Q_ASSERT(jt != headers.constEnd());
 
